parse_toml_coerce_default

Function parse_toml_coerce_default 

fn parse_toml_coerce_default<T: SolValue>(
    toml: &str,
    key: &str,
    ty: &DynSolType,
    default: &T,
) -> Result
Parse a TOML string and return the value at the given path, coercing it to the given type, or return the default if the path does not exist.