fn parse_toml_coerce_default<T: SolValue>(
toml: &str,
key: &str,
ty: &DynSolType,
default: &T,
) -> ResultExpand description
Parse a TOML string and return the value at the given path, coercing it to the given type, or return the default if the path does not exist.